@@ -1,6 +1,6 @@
 package ## Hide from PAUSE
  MooseX::Meta::TypeConstraint::Structured;
-# ABSTRACT: MooseX::Meta::TypeConstraint::Structured - Structured type constraints.
+# ABSTRACT: Structured type constraints
 
 use Moose;
 use Devel::PartialDump;
@@ -9,6 +9,23 @@ use MooseX::Meta::TypeCoercion::Structured;
 extends 'Moose::Meta::TypeConstraint';
 
 
+#pod =head1 DESCRIPTION
+#pod
+#pod A structure is a set of L<Moose::Meta::TypeConstraint> that are 'aggregated' in
+#pod such a way as that they are all applied to an incoming list of arguments.  The
+#pod idea here is that a Type Constraint could be something like, "An C<Int> followed by
+#pod an C<Int> and then a C<Str>" and that this could be done so with a declaration like:
+#pod
+#pod     Tuple[Int,Int,Str]; ## Example syntax
+#pod
+#pod So a structure is a list of type constraints (the C<Int,Int,Str> in the above
+#pod example) which are intended to function together.
+#pod
+#pod =attr type_constraints
+#pod
+#pod A list of L<Moose::Meta::TypeConstraint> objects.
+#pod
+#pod =cut
 
 has 'type_constraints' => (
     is=>'ro',
@@ -16,6 +33,14 @@ has 'type_constraints' => (
     predicate=>'has_type_constraints',
 );
 
+#pod =attr constraint_generator
+#pod
+#pod =for stopwords subref
+#pod
+#pod A subref or closure that contains the way we validate incoming values against
+#pod a set of type constraints.
+#pod
+#pod =cut
 
 has 'constraint_generator' => (
     is=>'ro',
@@ -36,6 +61,11 @@ sub _build_coercion {
     );
 }
 
+#pod =method validate
+#pod
+#pod Messing with validate so that we can support nicer error messages.
+#pod
+#pod =cut
 
 sub _clean_message {
     my $message = shift @_;
@@ -72,12 +102,29 @@ override 'validate' => sub {
     }
 };
 
+#pod =method generate_constraint_for ($type_constraints)
+#pod
+#pod Given some type constraints, use them to generate validation rules for an ref
+#pod of values (to be passed at check time)
+#pod
+#pod =cut
 
 sub generate_constraint_for {
     my ($self, $type_constraints) = @_;
     return $self->constraint_generator->($self, $type_constraints);
 }
 
+#pod =begin :prelude
+#pod
+#pod =for stopwords parameterize
+#pod
+#pod =end :prelude
+#pod
+#pod =method parameterize (@type_constraints)
+#pod
+#pod Given a ref of type constraints, create a structured type.
+#pod
+#pod =cut
 
 sub parameterize {
     my ($self, @type_constraints) = @_;
@@ -93,6 +140,14 @@ sub parameterize {
     );
 }
 
+#pod =method __infer_constraint_generator
+#pod
+#pod =for stopwords servicable
+#pod
+#pod This returns a CODEREF which generates a suitable constraint generator.  Not
+#pod user servicable, you'll never call this directly.
+#pod
+#pod =cut
 
 sub __infer_constraint_generator {
     my ($self) = @_;
@@ -108,6 +163,11 @@ sub __infer_constraint_generator {
     }
 }
 
+#pod =method compile_type_constraint
+#pod
+#pod hook into compile_type_constraint so we can set the correct validation rules.
+#pod
+#pod =cut
 
 around 'compile_type_constraint' => sub {
     my ($compile_type_constraint, $self, @args) = @_;
@@ -121,6 +181,11 @@ around 'compile_type_constraint' => sub {
     return $self->$compile_type_constraint(@args);
 };
 
+#pod =method create_child_type
+#pod
+#pod modifier to make sure we get the constraint_generator
+#pod
+#pod =cut
 
 around 'create_child_type' => sub {
     my ($create_child_type, $self, %opts) = @_;
@@ -130,6 +195,15 @@ around 'create_child_type' => sub {
     );
 };
 
+#pod =method is_a_type_of
+#pod
+#pod =method is_subtype_of
+#pod
+#pod =method equals
+#pod
+#pod Override the base class behavior.
+#pod
+#pod =cut
 
 sub equals {
     my ( $self, $type_or_name ) = @_;
@@ -198,6 +272,11 @@ sub is_subtype_of {
     }
 }
 
+#pod =method type_constraints_equals
+#pod
+#pod Checks to see if the internal type constraints are equal.
+#pod
+#pod =cut
 
 sub type_constraints_equals {
     my ( $self, $other ) = @_;
@@ -253,6 +332,14 @@ sub _type_constraints_op_any {
     return 0;
 }
 
+#pod =method get_message
+#pod
+#pod Give you a better peek into what's causing the error.  For now we stringify the
+#pod incoming deep value with L<Devel::PartialDump> and pass that on to either your
+#pod custom error message or the default one.  In the future we'll try to provide a
+#pod more complete stack trace of the actual offending elements
+#pod
+#pod =cut
 
 around 'get_message' => sub {
     my ($get_message, $self, $value) = @_;
@@ -261,28 +348,43 @@ around 'get_message' => sub {
     return $self->$get_message($value);
 };
 
+#pod =head1 SEE ALSO
+#pod
+#pod The following modules or resources may be of interest.
+#pod
+#pod L<Moose>, L<Moose::Meta::TypeConstraint>
+#pod
+#pod =cut
 
+no Moose;
 __PACKAGE__->meta->make_immutable(inline_constructor => 0);
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-MooseX::Meta::TypeConstraint::Structured - MooseX::Meta::TypeConstraint::Structured - Structured type constraints.
+MooseX::Meta::TypeConstraint::Structured - Structured type constraints
+
+=head1 VERSION
+
+version 0.32
+
+=for stopwords parameterize
 
 =head1 DESCRIPTION
 
 A structure is a set of L<Moose::Meta::TypeConstraint> that are 'aggregated' in
 such a way as that they are all applied to an incoming list of arguments.  The
-idea here is that a Type Constraint could be something like, "An Int followed by
-an Int and then a Str" and that this could be done so with a declaration like:
+idea here is that a Type Constraint could be something like, "An C<Int> followed by
+an C<Int> and then a C<Str>" and that this could be done so with a declaration like:
 
     Tuple[Int,Int,Str]; ## Example syntax
 
-So a structure is a list of Type constraints (the "Int,Int,Str" in the above
+So a structure is a list of type constraints (the C<Int,Int,Str> in the above
 example) which are intended to function together.
 
 =head1 ATTRIBUTES
@@ -293,14 +395,11 @@ A list of L<Moose::Meta::TypeConstraint> objects.
 
 =head2 constraint_generator
 
-A subref or closure that contains the way we validate incoming values against
-a set of type constraints.
-
 =head1 METHODS
 
 =head2 validate
 
-Messing with validate so that we can support niced error messages.
+Messing with validate so that we can support nicer error messages.
 
 =head2 generate_constraint_for ($type_constraints)
 
@@ -313,9 +412,6 @@ Given a ref of type constraints, create a structured type.
 
 =head2 __infer_constraint_generator
 
-This returns a CODEREF which generates a suitable constraint generator.  Not
-user servicable, you'll never call this directly.
-
 =head2 compile_type_constraint
 
 hook into compile_type_constraint so we can set the correct validation rules.
@@ -343,6 +439,16 @@ incoming deep value with L<Devel::PartialDump> and pass that on to either your
 custom error message or the default one.  In the future we'll try to provide a
 more complete stack trace of the actual offending elements
 
+=for stopwords subref
+
+A subref or closure that contains the way we validate incoming values against
+a set of type constraints.
+
+=for stopwords servicable
+
+This returns a CODEREF which generates a suitable constraint generator.  Not
+user servicable, you'll never call this directly.
+
 =head1 SEE ALSO
 
 The following modules or resources may be of interest.
@@ -363,11 +469,11 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Yuval Kogman <nothingmuch@woobling.org>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =item *
 
-Tomas Doran <bobtfish@bobtfish.net>
+Tomas (t0m) Doran <bobtfish@bobtfish.net>
 
 =item *
 
@@ -377,10 +483,9 @@ Robert Sedlacek <rs@474.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by John Napiorkowski.
+This software is copyright (c) 2008 by John Napiorkowski.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
